==> media_twig_tools-2.0.0-rc3.tar.gz: media_twig_tools/src/Form/SettingsForm.php <==
<?php

namespace Drupal\media_twig_tools\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\media_twig_tools\Config\MediaTwigToolsConfig;
use Drupal\media_twig_tools\Services\Bounce;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a Media Twig Tools form.
 */
class SettingsForm extends FormBase {

  /**
   * Conf.
   *
   * @var \Drupal\media_twig_tools\Config\MediaTwigToolsConfig
   */
  protected $conf;

  /**
   * Bounce.
   *
   * @var \Drupal\media_twig_tools\Services\Bounce
   */
  protected $bounce;

  /**
   * Dirs list.
   *
   * @var array
   */
  protected $dirs;

  /**
   * SettingsForm constructor.
   *
   * @param \Drupal\media_twig_tools\Config\MediaTwigToolsConfig $conf
   *   The media twig tools config.
   */
  public function __construct(MediaTwigToolsConfig $conf, Bounce $bounce) {
    $this->conf = $conf;
    $this->bounce = $bounce;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get(MediaTwigToolsConfig::SERVICE_NAME),
      $container->get(Bounce::SERVICE_ID),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'media_twig_tools_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Settings.
    $form['settings'] = $this->getSettingsFormPart($form_state, empty($form['clearer']));

    // Clear.
    $form['clearer'] = $this->getClearerFormPart($form_state);

    // Bounce.
    $form['bounce'] = $this->getBounceFormPart($form_state);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $triggeringElement = $form_state->getTriggeringElement();
    if (isset($triggeringElement['#submit_action']) && $submitAction = $triggeringElement['#submit_action']) {
      switch ($submitAction) {
        case 'clear':
          $this->clearImages($form_state);
          break;

        case 'save':
          $this->saveSettings($form_state);
          break;

        case 'deleteBounce':
          $this->deleteBounce($form_state);
          break;
      }
    }
  }

  /**
   * Init settings.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The formstate.
   * @param bool $open
   *   The part should be open by default.
   *
   * @return array
   *   The settings form part.
   */
  protected function getSettingsFormPart(FormStateInterface $form_state, $open = FALSE) {
    $settings = [
      '#type' => 'details',
      '#title' => $this->t('Settings'),
      '#tree' => TRUE,
      '#open' => $open,
    ];

    $settings[MediaTwigToolsConfig::FIELD_DIRNAME] = [
      '#type' => 'textfield',
      '#title' => $this->t('Built image directory name'),
      '#default_value' => $this->conf->getDirname(),
      '#description' => $this->t('The name of the directory of the generated images'),
      '#required' => TRUE,
    ];

    $settings[MediaTwigToolsConfig::FIELD_NO_STYLE] = [
      '#type' => 'machine_name',
      '#machine_name' => [
        'exists' => [$this->conf, 'existsNoStyleIdentifier'],
        'replace_pattern' => '[^a-z0-9_]+',
      ],
      '#title' => $this->t('No image style identifier'),
      '#description' => $this->t('The rule identifier of a no styled-image base'),
      '#default_value' => $this->conf->getNoStyle(),
      '#required' => TRUE,
    ];

    $settings[MediaTwigToolsConfig::FIELD_ALLOW_MAX_SIZE] = [
      '#type' => 'textfield',
      '#title' => $this->t('Allow max size (for image generation)'),
      '#default_value' => $this->conf->getAllowMaxSize(),
      '#description' => 'MB',
    ];

    $settings[MediaTwigToolsConfig::FIELD_ENABLE_FORMAT_BOUNCE] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable format bounce'),
      '#default_value' => $this->conf->isFormatBounceEnable(),
      '#description' => $this->t('If enabled, only printed urls will be able to generate new Media Twig Tools image styles.'),
    ];

    $settings[MediaTwigToolsConfig::FIELD_ENABLE_OVERSIZE_CHECK] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable oversize check'),
      '#default_value' => $this->conf->isOversizeCheckEnable(),
      '#description' => $this->t('If enabled, rules that possibly could generate an image larger than possible will not be printed.'),
    ];

    $settings['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Save settings'),
        '#submit_action' => 'save',
      ],
    ];

    return $settings;
  }

  /**
   * Init the clear images form part.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   *
   * @return array
   *   The form part.
   */
  protected function getClearerFormPart(FormStateInterface $form_state) {
    $clearer = [
      '#type' => 'details',
      '#title' => $this->t('Clear generated images'),
      '#open' => TRUE,
      '#tree' => TRUE,
      'actions' => [
        '#type' => 'actions',
        'submit' => [
          '#type' => 'submit',
          '#value' => $this->t('Delete generated images'),
          '#submit_action' => 'clear',
        ],
      ],
    ];

    // List of builder dirs.
    foreach ($this->conf->getDirs() as $type => $data) {
      $options = array_combine($data['files'], $data['files']);
      $options = array_map(function ($path) {
        $basename = basename($path);
        if ($imageStyle = $this->conf->getImageStyleStorage()->load($basename)) {
          return $imageStyle->label();
        }
        else {
          return $this->t('No image style') . '(' . $basename . ')';
        }
      }, $options);

      if (!empty($data['files'])) {
        $clearer['types'][$type] = [
          '#type' => 'checkboxes',
          '#title' => $this->t($type),
          '#options' => $options,
        ];
      }
    }

    if (!empty($clearer['types'])) {
      return $clearer;
    }

    return [];
  }

  /**
   * Save settings action.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  protected function saveSettings(FormStateInterface $form_state) {
    $settings = $form_state->getValue('settings');
    $this->conf
      ->setDirname($settings[MediaTwigToolsConfig::FIELD_DIRNAME])
      ->setNoStyle($settings[MediaTwigToolsConfig::FIELD_NO_STYLE])
      ->setAllowMaxSize($settings[MediaTwigToolsConfig::FIELD_ALLOW_MAX_SIZE])
      ->enableFormatBounce($settings[MediaTwigToolsConfig::FIELD_ENABLE_FORMAT_BOUNCE])
      ->enableOversizeCheck($settings[MediaTwigToolsConfig::FIELD_ENABLE_OVERSIZE_CHECK]);
  }

  /**
   * Clear images action.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The formstate.
   */
  protected function clearImages(FormStateInterface $form_state) {
    foreach ($form_state->getValues()['clearer']['types'] as $type) {
      foreach (array_filter($type) as $dirname) {
        $this->conf->clearDir($dirname);
      }
    }
  }

  /**
   * Build bounce form.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   *
   * @return array
   *   The bounce form.
   */
  protected function getBounceFormPart(FormStateInterface $form_state) {
    $form = [
      '#type' => 'details',
      '#title' => $this->t('Allowed formats'),
      '#open' => FALSE,
      '#tree' => TRUE,
    ];

    $allowed_formats = $this->bounce->getBounces();

    if (!empty($allowed_formats)) {
      $form[] = [
        '#type' => 'submit',
        '#value' => $this->t('Delete allowed formats'),
        '#submit_action' => 'deleteBounce',
      ];

      $form['table'] = [
        '#type' => 'table',
        '#header' => [
          'Token',
        ],
        '#rows' => array_map(function ($token) {
          return [$token];
        }, $allowed_formats),
      ];
    }


    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function deleteBounce(FormStateInterface $form_state) {
    $this->bounce->cleanBounce();
  }
}

==> media_twig_tools-2.1.0-rc1.tar.gz: media_twig_tools/src/Form/SettingsForm.php <==
<?php

namespace Drupal\media_twig_tools\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\media_twig_tools\Config\MediaTwigToolsConfig;
use Drupal\media_twig_tools\Services\Bounce;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a Media Twig Tools form.
 */
class SettingsForm extends FormBase {

  /**
   * Conf.
   *
   * @var \Drupal\media_twig_tools\Config\MediaTwigToolsConfig
   */
  protected MediaTwigToolsConfig $conf;

  /**
   * Bounce.
   *
   * @var \Drupal\media_twig_tools\Services\Bounce
   */
  protected Bounce $bounce;

  /**
   * SettingsForm constructor.
   *
   * @param \Drupal\media_twig_tools\Config\MediaTwigToolsConfig $conf
   *   The media twig tools config.
   * @param \Drupal\media_twig_tools\Services\Bounce $bounce
   *   The bounce.
   */
  public function __construct(MediaTwigToolsConfig $conf, Bounce $bounce) {
    $this->conf = $conf;
    $this->bounce = $bounce;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get(MediaTwigToolsConfig::SERVICE_NAME),
      $container->get(Bounce::SERVICE_ID),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'media_twig_tools_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Settings.
    $form['settings'] = $this->getSettingsFormPart($form_state, empty($form['clearer']));

    // Clear.
    $form['clearer'] = $this->getClearerFormPart($form_state);

    // Bounce.
    $form['bounce'] = $this->getBounceFormPart($form_state);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $triggering_element = $form_state->getTriggeringElement();
    if (isset($triggering_element['#submit_action']) && $submitAction = $triggering_element['#submit_action']) {
      switch ($submitAction) {
        case 'clear':
          $this->clearImages($form_state);
          break;

        case 'save':
          $this->saveSettings($form_state);
          break;

        case 'deleteBounce':
          $this->deleteBounce($form_state);
          break;
      }
    }
  }

  /**
   * Init settings.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The formstate.
   * @param bool $open
   *   The part should be open by default.
   *
   * @return array
   *   The settings form part.
   */
  protected function getSettingsFormPart(FormStateInterface $form_state, $open = FALSE) {
    $settings = [
      '#type' => 'details',
      '#title' => $this->t('Settings'),
      '#tree' => TRUE,
      '#open' => $open,
    ];

    $settings[MediaTwigToolsConfig::FIELD_DIRNAME] = [
      '#type' => 'textfield',
      '#title' => $this->t('Built image directory name'),
      '#default_value' => $this->conf->getDirname(),
      '#description' => $this->t('The name of the directory of the generated images'),
      '#required' => TRUE,
    ];

    $settings[MediaTwigToolsConfig::FIELD_NO_STYLE] = [
      '#type' => 'machine_name',
      '#machine_name' => [
        'exists' => [$this->conf, 'existsNoStyleIdentifier'],
        'replace_pattern' => '[^a-z0-9_]+',
      ],
      '#title' => $this->t('No image style identifier'),
      '#description' => $this->t('The rule identifier of a no styled-image base'),
      '#default_value' => $this->conf->getNoStyle(),
      '#required' => TRUE,
    ];

    $settings[MediaTwigToolsConfig::FIELD_ALLOW_MAX_SIZE] = [
      '#type' => 'textfield',
      '#title' => $this->t('Allow max size (for image generation)'),
      '#default_value' => $this->conf->getAllowMaxSize(),
      '#description' => 'MB',
    ];

    $settings[MediaTwigToolsConfig::FIELD_ENABLE_FORMAT_BOUNCE] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable format bounce'),
      '#default_value' => $this->conf->isFormatBounceEnable(),
      '#description' => $this->t('If enabled, only printed urls will be able to generate new Media Twig Tools image styles.'),
    ];

    $settings[MediaTwigToolsConfig::FIELD_ENABLE_OVERSIZE_CHECK] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable oversize check'),
      '#default_value' => $this->conf->isOversizeCheckEnable(),
      '#description' => $this->t('If enabled, rules that possibly could generate an image larger than possible will not be printed.'),
    ];

    $settings['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Save settings'),
        '#submit_action' => 'save',
      ],
    ];

    return $settings;
  }

  /**
   * Init the clear images form part.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   *
   * @return array
   *   The form part.
   */
  protected function getClearerFormPart(FormStateInterface $form_state) {
    $clearer = [
      '#type' => 'details',
      '#title' => $this->t('Clear generated images'),
      '#open' => TRUE,
      '#tree' => TRUE,
      'actions' => [
        '#type' => 'actions',
        'submit' => [
          '#type' => 'submit',
          '#value' => $this->t('Delete generated images'),
          '#submit_action' => 'clear',
        ],
      ],
    ];

    // List of builder dirs.
    foreach ($this->conf->getDirs() as $type => $data) {
      $options = array_combine($data['files'], $data['files']);
      $options = array_map(function ($path) {
        $basename = basename($path);
        if ($imageStyle = $this->conf->getImageStyleStorage()->load($basename)) {
          return $imageStyle->label();
        }
        else {
          return $this->t('No image style') . '(' . $basename . ')';
        }
      }, $options);

      if (!empty($data['files'])) {
        $clearer['types'][$type] = [
          '#type' => 'checkboxes',
          '#title' => $this->t($type),
          '#options' => $options,
        ];
      }
    }

    if (!empty($clearer['types'])) {
      return $clearer;
    }

    return [];
  }

  /**
   * Save settings action.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  protected function saveSettings(FormStateInterface $form_state) {
    $settings = $form_state->getValue('settings');
    $this->conf
      ->setDirname($settings[MediaTwigToolsConfig::FIELD_DIRNAME])
      ->setNoStyle($settings[MediaTwigToolsConfig::FIELD_NO_STYLE])
      ->setAllowMaxSize($settings[MediaTwigToolsConfig::FIELD_ALLOW_MAX_SIZE])
      ->enableFormatBounce($settings[MediaTwigToolsConfig::FIELD_ENABLE_FORMAT_BOUNCE])
      ->enableOversizeCheck($settings[MediaTwigToolsConfig::FIELD_ENABLE_OVERSIZE_CHECK]);
  }

  /**
   * Clear images action.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The formstate.
   */
  protected function clearImages(FormStateInterface $form_state) {
    foreach ($form_state->getValues()['clearer']['types'] as $type) {
      foreach (array_filter($type) as $dirname) {
        $this->conf->clearDir($dirname);
      }
    }
  }

  /**
   * Build bounce form.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   *
   * @return array
   *   The bounce form.
   */
  protected function getBounceFormPart(FormStateInterface $form_state) {
    $form = [
      '#type' => 'details',
      '#title' => $this->t('Allowed formats'),
      '#open' => FALSE,
      '#tree' => TRUE,
    ];

    $allowed_formats = $this->bounce->getBounces();

    if (!empty($allowed_formats)) {
      $form[] = [
        '#type' => 'submit',
        '#value' => $this->t('Delete allowed formats'),
        '#submit_action' => 'deleteBounce',
      ];

      $form['table'] = [
        '#type' => 'table',
        '#header' => [
          'Token',
        ],
        '#rows' => array_map(function ($token) {
          return [$token];
        }, $allowed_formats),
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function deleteBounce(FormStateInterface $form_state) {
    $this->bounce->cleanBounce();
  }

}
